package java.awt;

import java.util.Arrays;
import java.lang.ref.SoftReference;
import java.awt.image.ColorModel;
import java.awt.geom.AffineTransform;

public abstract class MultipleGradientPaint implements Paint
{
    final int transparency;
    final float[] fractions;
    final Color[] colors;
    final AffineTransform gradientTransform;
    final MultipleGradientPaint.CycleMethod cycleMethod;
    final MultipleGradientPaint.ColorSpaceType colorSpace;
    ColorModel model;
    float[] normalizedIntervals;
    boolean isSimpleLookup;
    SoftReference<int[][]> gradients;
    SoftReference<int[]> gradient;
    int fastGradientArraySize;
    
    MultipleGradientPaint(float[] array, Color[] array2, MultipleGradientPaint.CycleMethod cycleMethod, MultipleGradientPaint.ColorSpaceType colorSpace, AffineTransform tx) {
        if (array == null) {
            throw new NullPointerException("Fractions array cannot be null");
        }
        if (array2 == null) {
            throw new NullPointerException("Colors array cannot be null");
        }
        if (cycleMethod == null) {
            throw new NullPointerException("Cycle method cannot be null");
        }
        if (colorSpace == null) {
            throw new NullPointerException("Color space cannot be null");
        }
        if (tx == null) {
            throw new NullPointerException("Gradient transform cannot be null");
        }
        if (array.length != array2.length) {
            throw new IllegalArgumentException("Colors and fractions must have equal size");
        }
        if (array2.length < 2) {
            throw new IllegalArgumentException("User must specify at least 2 colors");
        }
        float n = -1.0f;
        int length = array.length;
        int i = 0;
        while (i < length) {
            float n2 = array[i];
            if (n2 < 0.0f || n2 > 1.0f) {
                throw new IllegalArgumentException("Fraction values must be in the range 0 to 1: " + n2);
            }
            if (n2 <= n) {
                throw new IllegalArgumentException("Keyframe fractions must be increasing: " + n2);
            }
            n = n2;
            ++i;
        }
        boolean n3 = false;
        boolean n4 = false;
        int length2 = array.length;
        int n5 = 0;
        if (array[0] != 0.0f) {
            n3 = true;
            ++length2;
            ++n5;
        }
        if (array[array.length - 1] != 1.0f) {
            n4 = true;
            ++length2;
        }
        System.arraycopy(array, 0, this.fractions = new float[length2], n5, array.length);
        System.arraycopy(array2, 0, this.colors = new Color[length2], n5, array2.length);
        if (!(n3 == 0)) {
            this.fractions[0] = 0.0f;
            this.colors[0] = array2[0];
        }
        if (!(n4 == 0)) {
            this.fractions[length2 - 1] = 1.0f;
            this.colors[length2 - 1] = array2[array2.length - 1];
        }
        this.colorSpace = colorSpace;
        this.cycleMethod = cycleMethod;
        this.gradientTransform = new AffineTransform(tx);
        int n6 = 1;
        for (int j = 0; j < array2.length; ++j) {
            n6 = (n6 != 0 && array2[j].getAlpha() == 255);
        }
        this.transparency = ((n6 != 0) ? 1 : 3);
        return;
    }
    
    public final float[] getFractions() {
        return Arrays.copyOf(this.fractions, this.fractions.length);
    }
    
    public final Color[] getColors() {
        return (Color[])Arrays.copyOf(this.colors, this.colors.length);
    }
    
    public final MultipleGradientPaint.CycleMethod getCycleMethod() {
        return this.cycleMethod;
    }
    
    public final MultipleGradientPaint.ColorSpaceType getColorSpace() {
        return this.colorSpace;
    }
    
    public final AffineTransform getTransform() {
        return new AffineTransform(this.gradientTransform);
    }
    
    @Override
    public final int getTransparency() {
        return this.transparency;
    }
    
    public enum CycleMethod
    {
        NO_CYCLE, 
        REFLECT, 
        REPEAT;
    }
    
    public enum ColorSpaceType
    {
        SRGB, 
        LINEAR_RGB;
    }
}
